@@ -1,12 +1,12 @@
 """ Root store module with easy imports for implemented Stores """
 from maggma.core import Store
-from maggma.stores.mongolike import MongoStore, MongoURIStore, JSONStore, MemoryStore
-from maggma.stores.gridfs import GridFSStore
 from maggma.stores.advanced_stores import (
-    MongograntStore,
-    VaultStore,
     AliasingStore,
+    MongograntStore,
     SandboxStore,
+    VaultStore,
 )
 from maggma.stores.aws import S3Store
-from maggma.stores.compound_stores import JointStore, ConcatStore
+from maggma.stores.compound_stores import ConcatStore, JointStore
+from maggma.stores.gridfs import GridFSStore
+from maggma.stores.mongolike import JSONStore, MemoryStore, MongoStore, MongoURIStore
